==> zio-aws-cloudfront_2.13-5.17.125.1-sources.jar: zio/aws/cloudfront/model/ListDistributionsByOriginRequestPolicyIdResponse.scala <==
package zio.aws.cloudfront.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class ListDistributionsByOriginRequestPolicyIdResponse(
    distributionIdList: Option[zio.aws.cloudfront.model.DistributionIdList] =
      None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.cloudfront.model.ListDistributionsByOriginRequestPolicyIdResponse = {
    import ListDistributionsByOriginRequestPolicyIdResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.cloudfront.model.ListDistributionsByOriginRequestPolicyIdResponse
      .builder()
      .optionallyWith(distributionIdList.map(value => value.buildAwsValue()))(
        _.distributionIdList
      )
      .build()
  }
  def asReadOnly
      : zio.aws.cloudfront.model.ListDistributionsByOriginRequestPolicyIdResponse.ReadOnly =
    zio.aws.cloudfront.model.ListDistributionsByOriginRequestPolicyIdResponse
      .wrap(buildAwsValue())
}
object ListDistributionsByOriginRequestPolicyIdResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.cloudfront.model.ListDistributionsByOriginRequestPolicyIdResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.cloudfront.model.ListDistributionsByOriginRequestPolicyIdResponse =
      zio.aws.cloudfront.model.ListDistributionsByOriginRequestPolicyIdResponse(
        distributionIdList.map(value => value.asEditable)
      )
    def distributionIdList
        : Option[zio.aws.cloudfront.model.DistributionIdList.ReadOnly]
    def getDistributionIdList: ZIO[
      Any,
      AwsError,
      zio.aws.cloudfront.model.DistributionIdList.ReadOnly
    ] = AwsError.unwrapOptionField("distributionIdList", distributionIdList)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.cloudfront.model.ListDistributionsByOriginRequestPolicyIdResponse
  ) extends zio.aws.cloudfront.model.ListDistributionsByOriginRequestPolicyIdResponse.ReadOnly {
    override val distributionIdList
        : Option[zio.aws.cloudfront.model.DistributionIdList.ReadOnly] = scala
      .Option(impl.distributionIdList())
      .map(value => zio.aws.cloudfront.model.DistributionIdList.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.cloudfront.model.ListDistributionsByOriginRequestPolicyIdResponse
  ): zio.aws.cloudfront.model.ListDistributionsByOriginRequestPolicyIdResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-cloudfront_2.13-5.17.187.1-sources.jar: zio/aws/cloudfront/model/ListDistributionsByOriginRequestPolicyIdResponse.scala <==
package zio.aws.cloudfront.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class ListDistributionsByOriginRequestPolicyIdResponse(
    distributionIdList: Optional[zio.aws.cloudfront.model.DistributionIdList] =
      Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.cloudfront.model.ListDistributionsByOriginRequestPolicyIdResponse = {
    import ListDistributionsByOriginRequestPolicyIdResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.cloudfront.model.ListDistributionsByOriginRequestPolicyIdResponse
      .builder()
      .optionallyWith(distributionIdList.map(value => value.buildAwsValue()))(
        _.distributionIdList
      )
      .build()
  }
  def asReadOnly
      : zio.aws.cloudfront.model.ListDistributionsByOriginRequestPolicyIdResponse.ReadOnly =
    zio.aws.cloudfront.model.ListDistributionsByOriginRequestPolicyIdResponse
      .wrap(buildAwsValue())
}
object ListDistributionsByOriginRequestPolicyIdResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.cloudfront.model.ListDistributionsByOriginRequestPolicyIdResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.cloudfront.model.ListDistributionsByOriginRequestPolicyIdResponse =
      zio.aws.cloudfront.model.ListDistributionsByOriginRequestPolicyIdResponse(
        distributionIdList.map(value => value.asEditable)
      )
    def distributionIdList
        : Optional[zio.aws.cloudfront.model.DistributionIdList.ReadOnly]
    def getDistributionIdList: ZIO[
      Any,
      AwsError,
      zio.aws.cloudfront.model.DistributionIdList.ReadOnly
    ] = AwsError.unwrapOptionField("distributionIdList", distributionIdList)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.cloudfront.model.ListDistributionsByOriginRequestPolicyIdResponse
  ) extends zio.aws.cloudfront.model.ListDistributionsByOriginRequestPolicyIdResponse.ReadOnly {
    override val distributionIdList
        : Optional[zio.aws.cloudfront.model.DistributionIdList.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.distributionIdList())
        .map(value => zio.aws.cloudfront.model.DistributionIdList.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.cloudfront.model.ListDistributionsByOriginRequestPolicyIdResponse
  ): zio.aws.cloudfront.model.ListDistributionsByOriginRequestPolicyIdResponse.ReadOnly =
    new Wrapper(impl)
}
